@@ -6,4 +6,4 @@ from quickstats.components.nuisance_parameter_pull import NuisanceParameterPull
 from quickstats.components.roofit_plotter import RooFitPlotter
 from quickstats.components.nuisance_parameter_harmonizer import NuisanceParameterHarmonizer
 from quickstats.components.analysis_object import AnalysisObject
-from quickstats.components.asymptotic_cls import AsymptoticsCLs
\ No newline at end of file
+from quickstats.components.asymptotic_cls import AsymptoticCLs
\ No newline at end of file
