@@ -171,6 +171,9 @@ class AsymptoticCLs(AnalysisObject):
         self.load_snapshot(self.nom_glob_name)
         return nll_val
     
+    def create_nll(self, dataset:"ROOT.RooDataSet"):
+        return self.pdf.createNLL(dataset, *self.minimizer.nll_command_list)
+        
     def get_qmu(self, nll:"ROOT.RooNLLVar", mu:float):
         nll_muhat = self.nll_maps[nll].get('nll_mu_hat', None)
         if nll_muhat is None:
@@ -444,7 +447,7 @@ class AsymptoticCLs(AnalysisObject):
         self.load_snapshot(snapshot_0_name)
         asimov_data_n = self.model.generate_asimov(self.poi.GetName(), poi_val=n_times_sigma,
                                                    do_conditional=True)
-        asimov_n_nll = self.pdf.createNLL(asimov_data_n, self.minimizer.nll_command_list)
+        asimov_n_nll = self.create_nll(asimov_data_n)
         self.load_conditional_snapshot(n_times_sigma, target="globs")
         self.load_conditional_snapshot(n_times_sigma, target="nuis")
         self.set_poi_value(n_times_sigma)
@@ -466,7 +469,7 @@ class AsymptoticCLs(AnalysisObject):
     def evaluate_limits(self):
         # TODO: maybe load nominal snapshot first
         self.reset()
-        obs_nll = self.pdf.createNLL(self.data, self.minimizer.nll_command_list)
+        obs_nll = self.create_nll(self.data)
         self.nll_maps[obs_nll] = {"dataset": self.data, "snapshot": self.nom_glob_name}
         self.dataset_maps[self.data] = obs_nll
         
@@ -476,7 +479,7 @@ class AsymptoticCLs(AnalysisObject):
         asimov_data_0 = self.model.generate_asimov(self.poi.GetName(), poi_val=0,
                                                    do_conditional=not self.do_blind,
                                                    poi_profile=0, dataset=self.data)
-        asimov_0_nll = self.pdf.createNLL(asimov_data_0, self.minimizer.nll_command_list)
+        asimov_0_nll = self.create_nll(asimov_data_0)
         self.summary[0] = {'dataset': asimov_data_0, 'nll': asimov_0_nll}
         self.set_poi_value(0)
         self.save_nll_snapshot(asimov_0_nll, 0)
